# Generated by Django 2.0.6 on 2018-11-28 10:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_yubin', '0004_message_date_sent'),
    ]

    operations = [
        migrations.AlterField(
            model_name='queuedmessage',
            name='priority',
            field=models.PositiveSmallIntegerField(choices=[(0, 'now'), (1, 'high'), (3, 'normal'), (5, 'low')], default=3),
        ),
    ]
