# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2017-04-05 14:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_yubin', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='queuedmessage',
            name='priority',
            field=models.PositiveSmallIntegerField(choices=[(1, 'high'), (3, 'normal'), (5, 'low'), (0, 'now')], default=3),
        ),
    ]
