# Generated by Django 2.0.6 on 2018-06-27 14:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_yubin', '0003_auto_20171201_1506'),
    ]

    operations = [
        migrations.AddField(
            model_name='message',
            name='date_sent',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
