# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-12-01 14:06
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_yubin', '0002_auto_20170405_1635'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='result',
            field=models.PositiveSmallIntegerField(choices=[(0, 'success'), (1, 'not sent (blacklisted or paused)'), (2, 'failure')]),
        ),
    ]
